@@ -2,10 +2,11 @@ import argparse
 
 from mohou.default import auto_detect_autoencoder_type
 from mohou.script_utils import visualize_image_reconstruction
+from mohou.setting import setting
 
 if __name__ == "__main__":
     parser = argparse.ArgumentParser()
-    parser.add_argument("-pn", type=str, default="kuka_reaching", help="project name")
+    parser.add_argument("-pn", type=str, default=setting.primary_project_name, help="project name")
     parser.add_argument("-n", type=int, default=5, help="number of visualization")
     args = parser.parse_args()
     project_name = args.pn
